igraph: A library for creating and manipulating graphs
======================================================

Description
-----------

igraph is a library for creating and manipulating graphs. It is intended
to be as powerful (ie. fast) as possible to enable the analysis of large
graphs.

License
-------

GPL version 2


Upstream Contact
----------------

http://igraph.org/c/

Dependencies
------------

igraph can optionally use libxml2 for providing a GraphML importer.


Special Update/Build Instructions
---------------------------------
